from .fake_data import (
    fake_male_first_name, 
    fake_female_first_name, 
    fake_last_name, 
    fake_username, 
    fake_email, 
    fake_phone_number, 
    fake_address, 
    fake_birthdate, 
    fake_company_name, 
    fake_user_agent
)




from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="mebularts",
    version="0.1.2",
    packages=find_packages(),
    install_requires=[],
    author="Mehmet Bulat",
    author_email="info@mebularts.com.tr",
    description=(
        "TR: @mebularts tarafından ♥ ile kodlanmıştır. Sahte Türk isim, soyisim, "
        "kullanıcı adı, adres, telefon numarası, doğum tarihi, şirket adı, email ve "
        "user_agent üretmek için ücretsiz bir kütüphane. "
        "EN: Coded with ♥ by @mebularts. A free library to generate fake Turkish names, "
        "surnames, usernames, addresses, phone numbers, dates of birth, company names, "
        "emails and user_agents."
    ),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://mebularts.com.tr/",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
